@@ -9,7 +9,7 @@ use parent qw/Cache::Memcached::Fast/;
 use POSIX::AtFork;
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $SANITIZE_METHOD = sub {
     my $key = shift;
     $key = uri_escape($key,"\x00-\x20\x7f-\xff");
@@ -117,6 +117,15 @@ for my $method (qw/get_multi gets_multi/) {
     }
 }
 
+sub get_or_set {
+    my($self, $key, $sub, $expire) = @_;
+    if (my $value = $self->get($key)) {
+        return $value;
+    }
+    my ($value, $ret_expire) = $sub->();
+    $self->set($key, $value, $expire || $ret_expire);
+    $value;
+}
 
 1;
 
@@ -143,6 +152,28 @@ Cache::Memcached::Fast::Safe sanitizes all requested keys for against
 memcached injection problem. and call disconnect_all automatically after fork 
 for fork-safe.
 
+=head1 ADDITIONAL METHOD
+
+=over 4
+
+=item get_or_set($key:Str, $callback:CodeRef [,$expires:Num])
+
+Get a cache value for $key if it's already cached. If can not retrieve cache values, execute $callback and cache with $expires seconds.
+
+  $memcached->get_or_set('key:941',sub {
+    DB->retrieve(941)
+  },10);
+
+callback can also return expires sec.
+
+  $memcached->get_or_set('key:941',sub {
+    my $val = DB->retrieve(941);
+    return ($val, 10)
+  });
+
+
+=back
+
 =head1 CUSTOMIZE Sanitizer
 
 This module allow to change sanitizing behavior through $Cache::Memcached::Fast::Safe::SANITIZE_METHOD.
